# Welcome to maeson


[![image](https://img.shields.io/pypi/v/maeson.svg)](https://pypi.python.org/pypi/maeson)


**Geospatial software for raster and point cloud processing.**


-   Free software: MIT License
-   Documentation: <https://dzfinch.github.io/maeson>
    

## Features

-   TODO
